clear all
clc
addpath /Users/rdchlaa9/Desktop/Denise_Grid/wave-tools/bin/matlab
% read meshbound
[tri0,x0,y0,z0]=readWW3mesh('meshbnd.msh',0);
ID=find(z0==3);
% read mesh
[tri,x,y,z]=readWW3mesh('45-1500_m.msh',0);
% calculate grid resolution
[dxtriF,dxnode] = dx_cart_mesh('45-1500_m.msh',0);
% load open boundary index
OBC=34:56;
% observations
 obs=[-75.5947        36.2605;     
 -75.7141        36.1999;    
 -75.7393        36.1893;    
 -75.7433        36.1883;    
 -75.7465        36.1873;   
 -75.7482        36.1868;    
 -75.7487        36.1868;     
 -75.7498        36.1865;    
 -75.7505        36.1863];     
obsi={'P26','P17','P11','P08','P06','P05','P04','P03','P02'};
%% %plot depth
width=1000;  % Width of figure for movie [pixels]
height=1000;  % Height of figure of movie [pixels]
left=200;     % Left margin between figure and screen edge [pixels]
bottom=200;  % Bottom margin between figure and screen edge [pixels]


h=figure;
set(gcf,'Position', [left bottom width height])

trisurf(tri,x,y,z);
shading interp
view(2)
hold on
p1=scatter3(x(ID),y(ID),z(ID)+1,50,'ok','filled')
hold on
p2=scatter3(x(OBC),y(OBC),z(OBC)+1,30,'om','filled')
hold on
p3=scatter3(obs(:,1),obs(:,2),100*ones(length(obs(:,1)),1),100,'pr','filled')
hold on
legend([p1,p2,p3],'lateral BC','Open BC','Obs','fontsize',20)
axis equal
colormap(summer)
hcb = colorbar('eastoutside');
set(get(hcb,'Xlabel'),'String','z [ m ]','Fontsize',20)
caxis([-5 25])
box on
axis on
grid on
xlabel('Longitude','Fontsize',14)
ylabel('Latitude','Fontsize',14)
print(gcf,'-dpng',['depth','.png'],'-r500');
%% %plot dx

h=figure;
set(gcf,'Position', [left bottom width height])

trisurf(tri,x,y,1000*dxnode);
shading interp
view(2)
hold on
p1=scatter3(x(ID),y(ID),1000*dxnode(ID)+1,50,'ok','filled')
hold on
p2=scatter3(x(OBC),y(OBC),1000*dxnode(OBC)+1,30,'om','filled')
hold on
scatter3(obs(:,1),obs(:,2),100*ones(length(obs(:,1)),1),100,'pr','filled')
hold on
axis equal
colormap(summer)
hcb = colorbar('eastoutside');
set(get(hcb,'Xlabel'),'String','\Deltax [ m ]','Fontsize',20)
box on
axis on
grid on
xlabel('Longitude','Fontsize',14)
ylabel('Latitude','Fontsize',14)
print(gcf,'-dpng',['dx','.png'],'-r500')

%% zoom in depth
h=figure;
set(gcf,'Position', [left bottom width height])
trisurf(tri,x,y,z);
shading interp
view(2)
hold on
p1=scatter3(x(ID),y(ID),z(ID)+1,50,'ok','filled')
hold on
scatter3(obs(:,1),obs(:,2),100*ones(length(obs(:,1)),1),100,'pr','filled')
hold on
axis equal
colormap(summer)
hcb = colorbar('eastoutside');
set(get(hcb,'Xlabel'),'String','z [ m ]','Fontsize',20)
caxis([-5 10])
box on
axis on
grid on
xlabel('Longitude','Fontsize',14)
ylabel('Latitude','Fontsize',14)
xlim([-75.78 -75.69])
ylim([36.14 36.23])
print(gcf,'-dpng',['depth_zoom','.png'],'-r500');
%% zoom in dx
h=figure;
set(gcf,'Position', [left bottom width height])
trisurf(tri,x,y,1000*dxnode);
view(2)
hold on
p1=scatter3(x(ID),y(ID),1000*dxnode(ID)+1,50,'ok','filled')
hold on
scatter3(obs(:,1),obs(:,2),100*ones(length(obs(:,1)),1),100,'pr','filled')
hold on
axis equal
colormap(summer)
hcb = colorbar('eastoutside');
set(get(hcb,'Xlabel'),'String','\Deltax [ m ]','Fontsize',20)
box on
axis on
grid on
xlabel('Longitude','Fontsize',14)
ylabel('Latitude','Fontsize',14)
xlim([-75.78 -75.69])
ylim([36.14 36.23])
print(gcf,'-dpng',['dx_zoom','.png'],'-r500');
%% % histogram

width=1000;  % Width of figure for movie [pixels]
height=1000;  % Height of figure of movie [pixels]
left=10;     % Left margin between figure and screen edge [pixels]
bottom=10;  % Bottom margin between figure and screen edge [pixels]

figure('Color','w');
set(gcf,'Position', [left bottom width height])

subplot(1,2,1)
ax = gca; 
ax.FontSize = 16;
set(gca,'Fontsize',20)
histogram(1000*dxnode,100,'Normalization','countdensity')
xlabel('\Deltax [ m ]','FontSize',20)
ylabel('Count Density','FontSize',20)
subplot(1,2,2)
text(0,4,['# of nodes  = ',num2str(length(x))],'FontSize',20)
text(0,3,['# of Elements = ',num2str(length(tri(:,1)))],'FontSize',20)
text(0,2,['\Deltax_{min} = ',num2str(1000*min(dxnode),'%.2f'),' m'],'FontSize',20)
text(0,1,['\Deltax_{max} = ',num2str(1000*max(dxnode),'%.2f'),' m'],'FontSize',20)
 set(gca,'Fontsize',20)
 xlim([-1 10])
 ylim([0 15])
box off
axis off
grid off
print(gcf,'-dpng',['histogram.png'],'-r500');
